/******************************************************************************************
This program creates the datasets used in the paper "International Mergers and Acquisitions 
Laws, the Market for Corporate Control and Accounting Conservatism." Two main datasets are 
created. The first dataset is used to implement the difference-in-differences (DID) analysis 
on the effect of M&A law adoption on conservatism and its real effects on leverage and capital 
investment. This sample consists of both firms in M&A law enacting countries and firms in 
nonenacting countries. The second dataset is used to conduct the event study analysis, which 
includes only firms in enacting countries and uses a symmetric four-year window around M&A law 
adoption. 
****************************************************************************************/

libname a'C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International takeover and conservatism\data';
libname b'C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\wrds dataset\Compustat Global';
libname c'C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\datastream data\provisions';

/* import firm-years from M&A law enacting countries. This dataset is compiled using
code KW2018_SASCODE1. */
data takeover;
	set a.takeovercountry;
run; 

/* obtain fiscal year beginning date for each firm-year */
data takeover1;
	set takeover;
	fybegdt = intnx('year',datadate,-1,'same')+1;
	format fybegdt YYMMDDN8.;
run;

/* remote connect to WRDS and upload TAKEOVER1 dataset and merge it with daily stock
price from Compustat Global Security Daily File**/
%let wrds = wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;

rsubmit;
libname comp'/wrds/comp/sasdata/global';
run;

proc upload data=takeover1 out=takeover2;
run;

proc sql;
	create table takeover3
	as select distinct a.*, b.prccd,b.ajexdi,b.trfd,b.datadate as date,b.iid
	from takeover2 as a left join comp.g_secd as b
	on a.gvkey=b.gvkey and a.fybegdt<=b.datadate<=a.datadate;
quit;

proc download data=takeover3 out=takeover4;
run;
endrsubmit;

proc sort data=takeover4; by gvkey fyear date iid; run;

proc sort data=takeover4 out=takeover5 nodupkey; by gvkey fyear date; run;


/** get adjusted stock price based upon daily adjustment factor and daily total 
return factor **/
data takeover6;
	set takeover5;
	prc = (prccd/ajexdi)*trfd;
run;

/* get lagged value */
data takeover7;
	set takeover6;
	lag_gvkey = lag(gvkey);
	lag_prc = lag(prc);

	if gvkey ne lag_gvkey then
	lag_prc=.;
	
	drop lag_gvkey;
run;

/* calculate daily stock return */
data takeover8;
	set takeover7;
	ret = prc/lag_prc -1;
run;

/* calculate buy and hold return over the fiscal year */
data takeover_ret;
	set takeover8;
	if ret=-1 then ret=-.9999999;
	lnret = log(1+ret);
run;

proc sql;
	create table takeover_ret1
	as select *, exp(sum(lnret)) as retexp
	from takeover_ret
	group by gvkey,fyear;
quit;

data takeover_ret2;
	set takeover_ret1;
	bhret = retexp -1;
run;

proc sort data=takeover_ret2 nodupkey out=takeover_ret3;
	by gvkey fyear;
run;

data takeover_ret4;
	set takeover_ret3;
	keep gvkey fyear datadate fybegdt fic bhret;
run;

/** get other variables in the Basu (1997) measure of asymmetric timeliness of loss 
recognition: market cap and earnings **/

/* market cap */
data mv;
	set b.g_funda;
	keep gvkey fyear datadate cshoi;
	where indfmt='INDL' and consol='C';
run;

/* upload to WRDS and merge with Compustat Global Security Daily File to get the most
recent stock price before or on fiscal year ending date */
%let wrds = wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;

rsubmit;
libname comp'/wrds/comp/sasdata/global';
run;

proc upload data=mv out=mv1;
run;

proc sql;
	create table mv2
	as select distinct a.*, b.prccd,b.datadate as datadate1,b.iid
	from mv1 as a left join comp.g_secd as b
	on a.gvkey=b.gvkey and
	a.datadate-50<=b.datadate<=a.datadate
	order by gvkey,datadate,datadate1;
quit;

proc download data=mv2 out=mv3;
run;
endrsubmit;

/* remove observations with missing stock price */
data mv4;
	set mv3;
	where prccd ne .;
run;

proc sort data=mv4; by gvkey fyear datadate1 iid; run;

proc sort data=mv4 nodupkey out=mv5;
by gvkey fyear datadate1;
run;

proc sort data=mv5; by gvkey fyear descending datadate1; run;

proc sort data=mv5 nodupkey out=mv6;
	by gvkey fyear;
run;

data mv7;
	set mv6;
	mv = cshoi * prccd;
run;

/* bring in earnings before extraordinary items from Compustat Global Fundamentals 
Annual File */
data ni;
	set b.g_funda;
	keep gvkey fyear ib;
	where indfmt='INDL' and consol='C';
run;

data ni1;
	set ni;
	if ib=. then delete;
run;

proc sort data=ni1 nodupkey;
	by gvkey fyear;
run;

/** merge TAKEOVER_RET4 dataset with earnings and market cap data **/
proc sql;
	create table basu_takeover
	as select a.*, b.ib
	from takeover_ret4 as a, ni1 as b
	where a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* merge with beginning of period market cap */
proc sql;
	create table basu_takeover1
	as select a.*, b.mv
	from basu_takeover as a left join mv7 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

/* delete observations with missing variables */
data basu_takeover2;
	set basu_takeover1;
	if bhret=. then delete;
	if mv=. then delete;
	if ib=. then delete;
run;

/* bring in takeover law enforcement year */
proc sql;
	create table basu_takeover3
	as select a.*, b.lawyear
	from basu_takeover2 as a, takeover as b
	where a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* construct the dependent variable and independent variables for the basu (1997) ATLR measure */
data basu_takeover4;
	set basu_takeover3;
	* earnings before extraordinary items divided by lagged mv;
	ni = ib/mv;
	* create a dummy variable NEG for negative annual stock returns;
	if bhret<0 then neg=1;
	else if bhret>=0 then neg=0;
run;

/** restrict the sample to 1992 - 2005 **/
data basu_takeover5;
	set basu_takeover4;
	where 1992<=fyear<=2005;
run;


/*******************************************************************************
*********Repeat the above code for firms in nonenacting countries***************
********************************************************************************/

/* bring in firm-years for nonenacting countries. This dataset is compiled using
code KW2018_SASCODE1. */
data nontakeover;
	set a.nontakeovercountry;
run;

/* obtain fiscal year beginning date for each firm-year */
data nontakeover1;
	set nontakeover;
	fybegdt = intnx('year',datadate,-1,'same')+1;
	format fybegdt YYMMDDN8.;
run;

/* remote connect to WRDS and upload dataset NONTAKEOVER1 and merge it with Compustat 
Global Security Daily File */
%let wrds = wrds.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;

rsubmit;
libname comp'/wrds/comp/sasdata/global';
run;

proc upload data=nontakeover1 out=nontakeover2;
run;

proc sql;
	create table nontakeover3
	as select distinct a.*, b.prccd,b.ajexdi,b.trfd,b.datadate as date,b.iid
	from nontakeover2 as a left join comp.g_secd as b
	on a.gvkey=b.gvkey and a.fybegdt<=b.datadate<=a.datadate;
quit;

proc download data=nontakeover3 out=nontakeover4;
run;
endrsubmit;

proc sort data=nontakeover4; by gvkey fyear date iid; run;

proc sort data=nontakeover4 out=nontakeover5 nodupkey;
	by gvkey fyear date;
run;

/* get adjusted stock price based upon daily adjustment factor and
daily total return factor */
data nontakeover6;
	set nontakeover5;
	prc = (prccd/ajexdi)*trfd;
run;

/* get lagged value */
data nontakeover7;
	set nontakeover6;
	lag_gvkey = lag(gvkey);
	lag_prc = lag(prc);

	if gvkey ne lag_gvkey then
	lag_prc=.;
	
	drop lag_gvkey;
run;

/* calculate return */
data nontakeover8;
	set nontakeover7;
	ret = prc/lag_prc -1;
run;

/* calculate buy and hold return over the fiscal year */
data nontakeover_ret;
	set nontakeover8;
	if ret=-1 then ret=-.9999999;
	lnret = log(1+ret);
run;

proc sql;
	create table nontakeover_ret1
	as select *, exp(sum(lnret)) as retexp
	from nontakeover_ret
	group by gvkey,fyear;
quit;

data nontakeover_ret2;
	set nontakeover_ret1;
	bhret = retexp -1;
run;

proc sort data=nontakeover_ret2 nodupkey out=nontakeover_ret3;
	by gvkey fyear;
run;

data nontakeover_ret4;
	set nontakeover_ret3;
	keep gvkey fyear datadate fybegdt fic bhret;
run;

/** merge NONTAKEOVER_RET4 data with earnings and market cap data for
firms in nonenacting countries **/
proc sql;
	create table basu_nontakeover
	as select a.*, b.ib
	from nontakeover_ret4 as a, ni1 as b
	where a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* beginning of period market cap */
proc sql;
	create table basu_nontakeover1
	as select a.*, b.mv
	from basu_nontakeover as a left join mv7 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

/* delete observations with missing variables */
data basu_nontakeover2;
	set basu_nontakeover1;
	if bhret=. then delete;
	if mv=. then delete;
	if ib=. then delete;
run;

/* set M&A law enactment year to missing for nonenacting countries */
data basu_nontakeover3;
	set basu_nontakeover2;
	lawyear=.;
run;

/* construct the dependent variable and independent variables for basu (1997) ATLR measure */
data basu_nontakeover4;
	set basu_nontakeover3;
	ni = ib/mv;
	if bhret<0 then neg=1;
	else if bhret>=0 then neg=0;
run; 

/* keep years from 1992 to 2005 */
data basu_nontakeover5;
	set basu_nontakeover4;
	where 1992<=fyear<=2005;
run;

/****************Control variables **********************/

/* SIZE */
data size;
	set b.g_funda;
	keep gvkey fyear datadate at curcd;
	where indfmt='INDL' and consol='C';
run;

data size1;
	set size;
	if at=. or at<=0 then delete;
run;

proc sort data=size1 nodupkey;
	by gvkey fyear;
run;

/* bring in exchange rate information from Compustat Global Exchange Rate Monthly File
to convert reported asset amounts to US dollar equivalents */
data exchange;
	set b.g_exrt_mth;
run;

data uscurrency;
	set exchange;
	where tocurm='USD';
run;

proc sql;
	create table exchange1
	as select a.tocurm,a.exratm,a.fromcurm,a.datadate,b.exratm as exratm1
	from exchange as a, uscurrency as b
	where a.datadate=b.datadate;
quit;

data exchange2;
	set exchange1;
	exratmus = exratm1/exratm;
run;

data exchange3;
	set exchange2;
	keep tocurm datadate exratmus;
run;

/* merge exchange rate with dataset SIZE1 */
proc sql;
	create table size2
	as select a.*, b.tocurm,b.exratmus
	from size1 as a left join exchange3 as b
	on a.curcd=b.tocurm and a.datadate=b.datadate
	order by gvkey,fyear;
quit;

/* convert reported asset amounts in native currency to US dollars and take 
the logarithm of the converted amount to proxy for firm size */
data size3;
	set size2;
	at1 = at*exratmus;
run;

data size4;
	set size3;
	size = log(at1);
run;

data size5;
	set size4;
	keep gvkey fyear at1 size;
run;

data size5a;
	set size5;
	rename at1=at;
run;

proc sort data=size5a nodupkey; by gvkey fyear; run;

/* get lagged size */
data size6;
	set size5a;
	lag_gvkey = lag(gvkey);
	lag_fyear = lag(fyear);
	lag_size = lag(size);

	if gvkey ne lag_gvkey or
	fyear ne lag_fyear+1 then
	lag_size=.;

	drop lag_gvkey lag_fyear;
run;

/* LEV */
data lev;
	set b.g_funda;
	keep gvkey fyear at dlc dltt;
	where indfmt='INDL' and consol='C';
run;

data lev1;
	set lev;
	if at=. or at<=0 then delete;
	if dlc=. then dlc=0;
	if dlc<0 and dlc ne . then delete;
	if dltt=. then dltt=0;
	if dltt<0 and dltt ne . then delete;
run;

proc sort data=lev1 nodupkey;
	by gvkey fyear;
run;

data lev2;
	set lev1;
	lev = (dlc+dltt)/at;
run;

proc sort data=lev2 nodupkey;
	by gvkey fyear;
run;

/* obtain lagged leverage ratio */
/* note: the lagged leverage ratio is used as a control variable in the main regression
analysis; The concurrent leverage ratio is used as the dependent variable in the analysis
on the effect of M&A laws on leverage, which will be merged to the dataset in a later step */
data lev3;
	set lev2;
	lag_gvkey = lag(gvkey);
	lag_fyear = lag(fyear);
	lag_lev = lag(lev);

	if gvkey ne lag_gvkey or
	fyear ne lag_fyear+1 then 
	lag_lev=.;

	drop lag_gvkey lag_fyear;
run;

/* MTB */
data mtb;
	set b.g_funda;
	keep gvkey fyear datadate ceq;
	where indfmt='INDL' and consol='C';
run;

data mtb1;
	set mtb;
	if ceq=. then delete;
run;

proc sort data=mtb1 nodupkey;
	by gvkey fyear;
run;

proc sql;
	create table mtb2
	as select a.*, b.mv
	from mtb1 as a, mv7 as b
	where a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

data mtb3;
	set mtb2;
	if ceq ne 0 then mtb=mv/ceq;
run;

proc sort data=mtb3 nodupkey;
	by gvkey fyear;
run;

/* obtain lagged MTB */
data mtb4;
	set mtb3;
	lag_gvkey = lag(gvkey);
	lag_fyear = lag(fyear);
	lag_mtb = lag(mtb);

	if gvkey ne lag_gvkey or 
	fyear ne lag_fyear+1 then 
	lag_mtb=.;

	drop lag_gvkey lag_fyear;
run;

/* RETVOL for firms in enacting countries. Use dataset TAKEOVER8 to compute standard 
deviation of daily returns over the fiscal year of firms in enacting countries. */
proc sql;
	create table retvol_takeover
	as select *, std(ret) as retvol
	from takeover8 
	group by gvkey,fyear
	order by gvkey,fyear,date;
quit;

proc sort data=retvol_takeover nodupkey;
	by gvkey fyear;
run;

/* RETVOL for firms in nonenacting countries. Use dataset NONTAKEOVER8 to compute standard 
deviation of daily returns over the fiscal year of firms in nonenacting countries. */
proc sql;
	create table retvol_nontakeover
	as select *, std(ret) as retvol
	from nontakeover8 
	group by gvkey,fyear
	order by gvkey,fyear,date;
quit;

proc sort data=retvol_nontakeover nodupkey;
	by gvkey fyear;
run;

/********* merge ATLR variables with control variables for main analysis *********/
/* enacting countries */
proc sql;
	create table basu_takeover6
	as select a.*, b.lag_size as size
	from basu_takeover5 as a left join size6 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_takeover7
	as select a.*, b.lag_lev as lev
	from basu_takeover6 as a left join lev3 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_takeover8
	as select a.*, b.lag_mtb as mtb
	from basu_takeover7 as a left join mtb4 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_takeover9
	as select a.*, b.retvol
	from basu_takeover8 as a left join retvol_takeover as b
	on a.gvkey=b.gvkey and a.fyear-1=b.fyear;
quit;

/* create POST and TREAT indicator variables for firms in enacting countries */
data basu_takeover10;
	set basu_takeover9;
	if fyear>=lawyear then post=1;
	else post=0;
	treat=1;
run;

/* nonenacting countries */
proc sql;
	create table basu_nontakeover6
	as select a.*, b.lag_size as size
	from basu_nontakeover5 as a left join size6 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_nontakeover7
	as select a.*, b.lag_lev as lev
	from basu_nontakeover6 as a left join lev3 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_nontakeover8
	as select a.*, b.lag_mtb as mtb
	from basu_nontakeover7 as a left join mtb4 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table basu_nontakeover9
	as select a.*, b.retvol
	from basu_nontakeover8 as a left join retvol_nontakeover as b
	on a.gvkey=b.gvkey and a.fyear-1=b.fyear;
quit;

/* create POST and TREAT indicator variables for firms in nonenacting countries */
data basu_nontakeover10;
	set basu_nontakeover9;
	post=0;
	treat=0;
run;

/* combine datasets for enacting countries and nonenacting countries for the DID analysis */
data total;	
	set basu_takeover10
		basu_nontakeover10;
run;

/* delete observations with missing variables */
data total1;
	set total;
	if neg=. then delete;
	if ni=. then delete;
	if bhret=. then delete;
	if post=. then delete;
	if size=. then delete;
	if mtb=. then delete;
	if lev=. then delete;
	if retvol=. then delete;
run;

/* winsorize at 1 and 99 percentile */
proc univariate data=total1 noprint;
	var ni bhret mtb lev retvol;
	output out=out1 pctlpts=1 99 pctlpre=ni bhret mtb lev retvol;
run;

proc sql;
	create table total2
	as select a.*, b.*
	from total1 as a, out1 as b;
quit;

data total3;
	set total2;
	if ni>ni99 and ni ne . then ni=ni99;
	if ni<ni1 and ni ne . then ni=ni1;
	if bhret>bhret99 and bhret ne . then bhret=bhret99;
	if bhret<bhret1 and bhret ne . then bhret=bhret1;
	if mtb>mtb99 and mtb ne . then mtb=mtb99;
	if mtb<mtb1 and mtb ne . then mtb=mtb1;
	if lev>lev99 and lev ne . then lev=lev99;
	if lev<lev1 and lev ne . then lev=lev1;
	if retvol>retvol99 and retvol ne . then retvol=retvol99;
	if retvol<retvol1 and retvol ne . then retvol=retvol1;

	drop ni1 ni99 bhret1 bhret99 mtb1 mtb99 lev1 lev99 retvol1 retvol99;
run;

/** demean control variables for the DID analysis **/
/* compute the sample mean for control vairables */
proc sql;
	create table total4
	as select *, avg(size) as avgsize, avg(mtb) as avgmtb, avg(lev) as avglev, avg(retvol) as avgretvol
	from total3;
quit;

/* substract out sample mean from actual value to obtain the demeaned variable */
data total5;
	set total4;
	sizec = size-avgsize;
	mtbc = mtb-avgmtb;
	levc = lev-avglev;
	retvolc = retvol-avgretvol;
run;

/************* Create variables for the real effects analysis **************/
/* capital investment */
data capx;
	set b.g_funda;
	keep gvkey fyear datadate capx ppent;
	where indfmt='INDL' and consol='C';
run;

data capx1;
	set capx;
	if capx=. then delete;
	if ppent<=0 then delete;
run;

proc sort data=capx1 nodupkey;
	by gvkey fyear;
run;

data capx2;
	set capx1;
	lag_gvkey =  lag(gvkey);
	lag_fyear = lag(fyear);
	lag_ppent = lag(ppent);

	if gvkey ne lag_gvkey or
	fyear ne lag_fyear+1 then
	lag_ppent=.;

	drop lag_gvkey lag_fyear;
run;

data capx3;
	set capx2;
	invest = capx/lag_ppent;
run;

/** Control variables **/

/* LOSS */
data loss;
	set b.g_funda;
	keep gvkey fyear at ib;
	where indfmt='INDL' and consol='C';
run;

data loss1;
	set loss;
	if at=. or at<=0 then delete;
	if ib=. then delete;
run;

proc sort data=loss1 nodupkey;
	by gvkey fyear;
run;

data loss2;
	set loss1;
	lag_gvkey = lag(gvkey);
	lag_fyear = lag(fyear);
	lag_at=lag(at);

	if gvkey ne lag_gvkey or
	fyear ne lag_fyear+1 then 
	lag_at=.;

	drop lag_gvkey lag_fyear;
run;

data loss3;
	set loss2;
	roa = ib/lag_at;
run;

data loss4;
	set loss3;
	if roa<0 and roa ne . then loss=1;
	else if roa>=0 then loss=0;
run;

/* CASH */
data cash;
	set b.g_funda;
	keep gvkey fyear at che;
	where indfmt='INDL' and consol='C';
run;

data cash1;
	set cash;
	if at=. or at<=0 then delete;
	if che=. or che<0 then delete;
run;

proc sort data=cash1 nodupkey;
	by gvkey fyear;
run;

data cash2;
	set cash1;
	cash = che/at;
run;

/* ZSCORE */
data zscore;
	set b.g_funda;
	keep gvkey fyear datadate pi sale re act dlc at;
	where indfmt='INDL' and consol='C';
run;

data zscore1;
	set zscore;
	if at<=0 then delete;
run;

proc sort data=zscore1 nodupkey;
	by gvkey fyear;
run;

data zscore2;
	set zscore1;
	zscore = (3.3*pi + sale + 1.4*re + 1.2*act - 1.2*dlc)/at;
run;

/* PPENT */
data ppent;
	set b.g_funda;
	keep gvkey fyear ppent at;
	where indfmt='INDL' and consol='C';
run;

data ppent1;
	set ppent;
	if at=. or at<=0 then delete;
	if ppent<=0 then delete;
run;

proc sort data=ppent1 nodupkey;
	by gvkey fyear;
run;

data ppent2;
	set ppent1;
	ppent = ppent/at;
run;

/* STDCF */
data cf;
	set b.g_funda;
	keep gvkey fyear fic datadate at act lct che dlc dd1 dp txp oiadp;
	where indfmt='INDL' and consol='C';
run;

data cf1;
	set cf;
	if at=. or at<0 then delete;
	if act=. or act<0 then delete;
	if che=. or che<0 then delete;
	if lct=. then lct=0;
	if lct<0 and lct ne . then delete;
	if dlc=. then dlc=0;
	if dlc<0 and dlc ne . then delete;
	if dp=. or dp<0 then delete;
	if txp=. then delete;
	if oiadp=. then delete;
run;

proc sort data=cf1 nodupkey;
	by gvkey fyear;
run;

data cf2;
	set cf1;
	lag_gvkey = lag(gvkey);
	lag_fyear = lag(fyear);
	lag_at = lag(at);
	lag_act = lag(act);
	lag_lct = lag(lct);
	lag_che = lag(che);
	lag_dlc = lag(dlc);
	lag_txp = lag(txp);

	if gvkey ne lag_gvkey or 
	fyear ne lag_fyear+1 then do
	lag_at=.;
	lag_act=.;
	lag_lct=.;
	lag_che=.;
	lag_dlc=.;
	lag_txp=.;
	end;

	drop lag_gvkey lag_fyear;
run;

data cf3;
	set cf2;
	chgact = act - lag_act;
	chglct = lct - lag_lct;
	chgche = che - lag_che;
	chgdlc = dlc - lag_dlc;
	chgtxp = txp - lag_txp;
run;

data cf4;
	set cf3;
	cf = oiadp - chgact + chgche - chglct + chgdlc + chgtxp - dp;
run;

data cf5;
	set cf4;
	cf = cf/lag_at;
run;

proc sql;
	create table cf6
	as select a.*, b.fyear as fyear1, b.cf as cf1
	from cf5 as a, cf5 as b
	where a.gvkey=b.gvkey and a.fyear-5<=b.fyear<=a.fyear-1
	order by gvkey,fyear,fyear1;
quit;

proc sql;
	create table cf7
	as select *, std(cf1) as stdcf
	from cf6
	group by gvkey,fyear
	order by gvkey,fyear,fyear1;
quit;

proc sort data=cf7 nodupkey;
	by gvkey fyear;
run;

/* STDSALE */
data sale;
	set b.g_funda;
	keep gvkey fyear sale at;
	where indfmt='INDL' and consol='C';
run;

data sale1;
	set sale;
	if at=. or at<=0 then delete;
run;

proc sort data=sale1 nodupkey;
	by gvkey fyear;
run;

data sale2;
	set sale1;
	lag_gvkey =  lag(gvkey);
	lag_fyear =  lag(fyear);
	lag_at = lag(at);
	
	if gvkey ne lag_gvkey or
	fyear ne lag_fyear+1 then
	lag_at=.;

	drop lag_gvkey lag_fyear;
run;

data sale3;
	set sale2;
	sale = sale/lag_at;
run;

proc sql;
	create table sale4
	as select a.*, b.fyear as fyear1, b.sale as sale1
	from sale3 as a, sale3 as b
	where a.gvkey=b.gvkey and a.fyear-5<=b.fyear<=a.fyear-1
	order by gvkey,fyear,fyear1;
quit;

proc sql;
	create table sale5
	as select *, std(sale1) as stdsale
	from sale4
	group by gvkey,fyear
	order by gvkey,fyear,fyear1;
quit;

proc sort data=sale5 nodupkey;
	by gvkey fyear;
run;


/** merge the TOTAL5 dataset with additional dependent variables and control 
variables for real effects analysis **/
/* bring in capital investment as a dependent variable */
proc sql;
	create table total6
	as select a.*, b.invest
	from total5 as a left join capx3 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* bring in concurrent leverage ratio as a dependent variable */
proc sql;
	create table total6a
	as select a.*, b.lev as leverage
	from total6 as a left join lev3 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* bring in control variables */
proc sql;
	create table total6b
	as select a.*, b.loss
	from total6a as a left join loss4 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

proc sql;
	create table total6c
	as select a.*, b.cash
	from total6b as a left join cash2 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

proc sql;
	create table total6d
	as select a.*, b.zscore
	from total6c as a left join zscore2 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

proc sql;
	create table total6e
	as select a.*, b.ppent
	from total6d as a left join ppent2 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear+1;
quit;

proc sql;
	create table total6f
	as select a.*, b.stdcf
	from total6e as a left join cf7 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

proc sql;
	create table total6g
	as select a.*, b.stdsale
	from total6f as a left join sale5 as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* winsorize variables for real effects analysis at the 1 and 99 percentile */
proc univariate data=total6g noprint;
	var invest leverage cash zscore ppent stdcf stdsale;
	output out=out2 pctlpts=1 99 pctlpre=invest leverage cash zscore ppent stdcf 
	stdsale;
run;

proc sql;
	create table total7
	as select a.*, b.*
	from total6g as a, out2 as b;
quit; 

data total7a;
	set total7;
	if invest>invest99 and invest ne . then invest=invest99;
	if invest<invest1 and invest ne . then invest=invest1;
	if leverage>leverage99 and leverage ne . then leverage=leverage99;
	if leverage<leverage1 and leverage ne . then leverage=leverage1;
	if cash>cash99 and cash ne . then cash=cash99;
	if cash<cash1 and cash ne . then cash=cash1;
	if zscore>zscore99 and zscore ne . then zscore=zscore99;
	if zscore<zscore1 and zscore ne . then zscore=zscore1;
	if ppent>ppent99 and ppent ne . then ppent=ppent99;
	if ppent<ppent1 and ppent ne . then ppent=ppent1;
	if stdcf>stdcf99 and stdcf ne . then stdcf=stdcf99;
	if stdcf<stdcf1 and stdcf ne . then stdcf=stdcf1;
	if stdsale>stdsale99 and stdsale ne . then stdsale=stdsale99;
	if stdsale<stdsale1 and stdsale ne . then stdsale=stdsale1;

	drop invest1 invest99 leverage1 leverage99 cash1 cash99
	zscore1 zscore99 ppent1 ppent99 stdcf1 stdcf99 stdsale1 stdsale99;
run;

/******** Additional country-level control variables *********/

/** GDP GROWTH **/
/* import GDP per capita data from local drive and then compute GDP per capita growth. 
Raw GDP data are from The World Bank */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\GDP per capita.xlsx' dbms=xlsx
out=gdp replace;
run;

proc sort data=gdp;
	by country_code year;
run;

/* get lagged GDP per capita */
data gdp1;
	set gdp;
	lag_countrycode = lag(country_code);
	lag_gdpper = lag(gdpper);

	if country_code ne lag_countrycode then
	lag_gdpper=.;

	drop lag_countrycode;
run;

/* compute growth in GDP per capita */
data gdp2;
	set gdp1;
	gdpgrowth = gdpper/lag_gdpper;
run;

/** JUDICIAL IMPARTIALITY & SOE **/
/* Raw data are from the Economic Freedom of the World 2014 Annual Report, which
are saved in local drive */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\economic freedom data.xlsx'
dbms=xlsx replace out=economic;
run;

data economic1;
	set economic;
	rename _2B__Impartial_courts=impartial;
	soe = _1C__Government_enterprises_and * 1;
run;

/** FINANCIAL REFORM **/
/* Raw data are from Abiad et al. (2012) which are saved in local drive */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\
Financial Reform Dataset Dec 2008.xls' dbms=xls out=finreform replace;
sheet='Data';
run;

/** INSIDER TRADING LAW ENFORCEMENT **/
/* Raw data are from Bhattacharya and Daouk (2002) which are saved in locla drive **/
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\international data.xlsx'
out=it dbms=xlsx replace;
run;

data it1;
	set it;
	rename insider_trading_enforcement = itenforce;
run;

/** SHORTLEGAL **/
/* Raw data are from Jain et al. (2013) which are saved in local drive */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\
Short selling.xlsx' dbms=xlsx out=shortsell replace;
run;

/** EPL **/
/* Raw data are from OECD index of employment protection legislation which are saved in 
local drive */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\EPL-timeseries.xlsx'
dbms=xlsx out=epl replace;
sheet="Summary indicators";
run;

/* merge TOTAL7A dataset with additional country level control variables constructed above */
proc sql;
	create table total8
	as select a.*, b.gdpgrowth
	from total7a as a left join gdp2 as b
	on a.fic=b.country_code and a.fyear=b.year;
quit;

proc sql;
	create table total8a
	as select a.*, b.impartial, b.soe
	from total8 as a left join economic1 as b
	on a.fic=b.ISO_Code and a.fyear=b.year;
quit;

proc sql;
	create table total8b
	as select a.*, b.finreform_n as finreform
	from total8a as a left join finreform as b
	on a.fic=b.wdi and a.fyear=b.year;
quit;

proc sql;
	create table total8c
	as select a.*, b.itenforce
	from total8b as a left join it1 as b
	on a.fic=b.countrycode;
quit; 

data total8d;
	set total8c;
	if itenforce=. then postit=0;
	else if fyear>=itenforce and itenforce ne . then postit=1;
	else if fyear<itenforce and itenforce ne . then postit=0;
run;

proc sql;
	create table total8e
	as select a.*, b.legal as shortlegal
	from total8d as a left join shortsell as b
	on a.fic=b.countrycode and a.fyear=b.year;
quit;

proc sql;
	create table total8f
	as select a.*, b.eprc_v1 as epl
	from total8e as a left join  epl as b
	on a.fic=b.ctry and a.fyear=b.year;
quit;

/* Demean country-level control variables */
proc sql;
	create table total9
	as select *, avg(gdpgrowth) as avg_gdpgrowth, avg(impartial) as avg_impartial,
	avg(soe) as avg_soe, avg(finreform) as avg_finreform, avg(postit) as 
	avg_postit, avg(shortlegal) as avg_shortlegal, avg(epl) as avg_epl
	from total8f;
quit;

data total9a;
	set total9;
	gdpgrowthc = gdpgrowth - avg_gdpgrowth;
	impartialc = impartial - avg_impartial;
	soec = soe - avg_soe;
	finreformc = finreform - avg_finreform;
	postitc = postit - avg_postit;
	shortlegalc = shortlegal - avg_shortlegal;
	eplc = epl - avg_epl;
run;

/***************** Additional conservatism measurs ****************/
/** Provision for bad debt variable from Datastream Worldscope **/
/* Raw data are from Datastream Worldscope. Provisions for bad debt (PROBD)) are defined as provisions
for uncollectible accounts receivables (WC18298) scaled by net receivables (WC02051) */

data takeover_probd;
	set c.takeoverprovision;
run;

data nontakeover_probd;
	set c.nontakeoverprovision;
run;

data probd;
	set takeover_probd
		nontakeover_probd;
run;

proc sql;
	create table total10
	as select a.*, b.probd 
	from total9a as a left join probd as b
	on a.gvkey=b.gvkey and a.fyear=b.year;
quit;

/* bring in special item (scaled by market cap) and accrued expense 
(scaled by net sale) variables. The raw data are from Compustat Global Fundamentals 
Annual File.*/
data cons_item;
	set a.cons_item;
run; 

proc sql;
	create table total10a 
	as select a.*, b.spi_mv as spi, b.accxp_sale as accxp
	from total10 as a left join cons_item as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* bring in SG&A (scaled by net sales. Raw data are from Compustat Global Fundamentals 
Annual File. */

data sga;
	set a.sga;
run;

proc sql;
	create table total10b
	as select a.*, b.sga
	from total10a as a left join sga as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;


/* bring in accrual and change in cash flow variables (both scaled by lagged assets, where
accrual is defined as earnings before extraordinary items minus operating cash flows 
(Compustat Item IBC - OANCF). Raw data are from Compustat Global Fundamentals Annual File. */

data accrual_cf;
	set a.accrual_cf;
run;

proc sql;
	create table total10c
	as select a.*, b.accrual1 as accrual_at, b.chgcfo1 as chgcfo
	from total10b as a left join accrual_cf as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit;

/* create dummy variable for decreases in operating cash flow */
data total10d;
	set total10c;
	if chgcfo<0 and chgcfo ne . then dchgcfo=1;
	else if chgcfo>=0 and chgcfo ne . then dchgcfo=0;
run;

/* also bring in accrual scaled by beginning market cap variable */
proc sql;
	create table total10e
	as select a.*, b.accrual2 as accrual_mv
	from total10d as a left join accrual_cf as b
	on a.gvkey=b.gvkey and a.fyear=b.fyear;
quit; 

/* winsorize other conservatism variables at the 1 and 99 percentile */
proc univariate data=total10e noprint;
	var probd spi accxp sga accrual_at chgcfo accrual_mv;
	output out=out3 pctlpts=1 99 pctlpre=probd spi accxp sga accrualat chgcfo
	accrualmv;
run;

proc sql;
	create table total11
	as select a.*, b.*
	from total10e as a, out3 as b;
quit;

data total11a;
	set total11;
	if probd>probd99 and probd ne . then probd=probd99;
	if probd<probd1 and probd ne . then probd=probd1;
	if spi>spi99 and spi ne . then spi=spi99;
	if spi<spi1 and spi ne . then spi=spi1;
	if accxp>accxp99 and accxp ne . then accxp=accxp99;
	if accxp<accxp1 and accxp ne . then accxp=accxp1;
	if sga>sga99 and sga ne . then sga=sga99;
	if sga<sga1 and sga ne . then sga=sga1;
	if accrual_at>accrualat99 and accrual_at ne . then accrual_at=accrualat99;
	if accrual_at<accrualat1 and accrual_at ne . then accrual_at=accrualat1;
	if chgcfo>chgcfo99 and chgcfo ne . then chgcfo=chgcfo99;
	if chgcfo<chgcfo1 and chgcfo ne . then chgcfo=chgcfo1;
	if accrual_mv>accrualmv99 and accrual_mv ne . then accrual_mv=accrualmv99;
	if accrual_mv<accrualmv1 and accrual_mv ne . then accrual_mv=accrualmv1;

	drop probd1 probd99 spi1 spi99 accxp1 accxp99 sga1 sga99 accrualat1
	accrualat99 chgcfo1 chgcfo99 accrualmv1 accrualmv99;
run;


/* Export dataset TOTAL11A to STATA for DID analysis */
proc export data=total11a outfile='C:\Users\Wei-Wang-T470\Desktop\My Research\
My SAS Files\International takeover and conservatism\stata\total.dta' replace;
run;


/*********************************************************************************
*****This part of the code sets up the dataset for the event study framework******
*********************************************************************************/

/* retian only treatment firms and compute the year gap between the current year 
and the year of M&A law enactment */
data event;
	set total11a;
	where treat=1;
	yeardiff = fyear - lawyear;
run;

/* retain only observations within [-4,+4] window around M&A law enactment */
data event1;
	set event;
	where -4<=yeardiff<=4;
run;

proc sort data=event1 nodupkey; by gvkey fyear;run;

/* define POST indicator variable for event study and remove the year of enactment to create
a symmetric 4-year window around M&A law enactment */	
data event2;
	set event1;
	if 0<yeardiff<=4 then post=1;
	else if -4<=yeardiff<0 then post=0;
	if yeardiff=0 then delete;
run;

/* retain only firms that appear in both the pre- and the post-period */ 
proc sql;
	create table event3
	as select *, max(post) as maxpost, min(post) as minpost
	from event2
	group by gvkey;
quit;

data event4;
	set event3;
	if maxpost=0 then delete;
	if minpost=1 then delete;
run;

/* demean control variables for event framework */
data event5;
	set event4;
	drop avgsize avgmtb avglev avgretvol sizec mtbc levc retvolc;
run;

proc sql;
	create table event5a
	as select *, avg(size) as avgsize, avg(mtb) as avgmtb, avg(lev) as avglev, avg(retvol) as avgretvol
	from event5;
quit;

data event5b;
	set event5a;
	sizec = size-avgsize;
	mtbc = mtb-avgmtb;
	levc = lev-avglev;
	retvolc = retvol-avgretvol;
run;

/* export dataset EVENT5B to STATA for event study analysis */
proc export data=event5b outfile='C:\Users\Wei-Wang-T470\Desktop\My Research\
My SAS Files\International takeover and conservatism\stata\event.dta' replace;
run;


